@@ -1,7 +1,7 @@
 // drumkv1_fx.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -22,9 +22,9 @@
 #ifndef __drumkv1_fx_h
 #define __drumkv1_fx_h
 
-#include <stdint.h>
-#include <stdlib.h>
-#include <math.h>
+#include <cstdint>
+#include <cstdlib>
+#include <cmath>
 
 
 //-------------------------------------------------------------------------
@@ -264,7 +264,7 @@ public:
 			// process
 			const float lo = m_lo.output(m_mi.output(m_hi.output(*in + ad)));
 			// compute peak
-			const float peak = ::fabs(lo);
+			const float peak = ::fabsf(lo);
 			// compute gain
 			float gain = 1.0f;
 			if (peak > threshold)
@@ -508,7 +508,7 @@ private:
 
 
 //-------------------------------------------------------------------------
-// drumkv1_fx_allpass_delay - All-pass delay implementation.
+// drumkv1_fx_allpass - All-pass delay implementation.
 
 class drumkv1_fx_allpass
 {
