@@ -1,7 +1,7 @@
 // drumkv1_lv2.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -63,8 +63,8 @@
 #define LV2_ATOM__portTuple LV2_ATOM_PREFIX "portTuple"
 #endif
 
-#include <stdlib.h>
-#include <math.h>
+#include <cstdlib>
+#include <cmath>
 
 #include <QApplication>
 #include <QDomDocument>
@@ -250,14 +250,14 @@ drumkv1_lv2::drumkv1_lv2 (
 		if (host_option->type == m_urids.atom_Int) {
 			uint32_t block_length = 0;
 			if (host_option->key == m_urids.bufsz_minBlockLength)
-				block_length = *(int *) host_option->value;
+				block_length = *(int32_t *) host_option->value;
 			else
 			if (host_option->key == m_urids.bufsz_maxBlockLength)
-				block_length = *(int *) host_option->value;
+				block_length = *(int32_t *) host_option->value;
 		#ifdef LV2_BUF_SIZE__nominalBlockLength
 			else
 			if (host_option->key == m_urids.bufsz_nominalBlockLength)
-				block_length = *(int *) host_option->value;
+				block_length = *(int32_t *) host_option->value;
 		#endif
 			// choose the lengthier...
 			if (buffer_size < block_length)
@@ -400,7 +400,7 @@ void drumkv1_lv2::run ( uint32_t nframes )
 							drumkv1_sample *pSample = drumkv1::sample();
 							if (pSample) {
 								const uint32_t offset_start
-									= *(uint32_t *) LV2_ATOM_BODY_CONST(value);
+									= *(int32_t *) LV2_ATOM_BODY_CONST(value);
 								const uint32_t offset_end
 									= pSample->offsetEnd();
 								setOffsetRange(offset_start, offset_end, true);
@@ -417,15 +417,15 @@ void drumkv1_lv2::run ( uint32_t nframes )
 								const uint32_t offset_start
 									= pSample->offsetStart();
 								const uint32_t offset_end
-									= *(uint32_t *) LV2_ATOM_BODY_CONST(value);
+									= *(int32_t *) LV2_ATOM_BODY_CONST(value);
 								setOffsetRange(offset_start, offset_end, true);
 							}
 						}
 						else
 						if (key == m_urids.p201_tuning_enabled
 							&& type == m_urids.atom_Bool) {
-							const uint32_t enabled
-								= *(uint32_t *) LV2_ATOM_BODY_CONST(value);
+							const int32_t enabled
+								= *(int32_t *) LV2_ATOM_BODY_CONST(value);
 							drumkv1::setTuningEnabled(enabled > 0);
 							updateTuning();
 						}
@@ -440,8 +440,8 @@ void drumkv1_lv2::run ( uint32_t nframes )
 						else
 						if (key == m_urids.p203_tuning_refNote
 							&& type == m_urids.atom_Int) {
-							const uint32_t refNote
-								= *(uint32_t *) LV2_ATOM_BODY_CONST(value);
+							const int32_t refNote
+								= *(int32_t *) LV2_ATOM_BODY_CONST(value);
 							drumkv1::setTuningRefNote(refNote);
 							updateTuning();
 						}
