@@ -1,7 +1,7 @@
 // drumkv1_ramp.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -22,8 +22,8 @@
 #ifndef __drumkv1_ramp_h
 #define __drumkv1_ramp_h
 
-#include <stdint.h>
-#include <math.h>
+#include <cstdint>
+#include <cmath>
 
 
 //-------------------------------------------------------------------------
