@@ -1,7 +1,7 @@
 // drumkv1_sample.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -22,10 +22,11 @@
 #ifndef __drumkv1_sample_h
 #define __drumkv1_sample_h
 
-#include <stdint.h>
+#include <cstdint>
+
+#include <cstdlib>
+#include <cstring>
 
-#include <stdlib.h>
-#include <string.h>
 
 // forward decls.
 class drumkv1;
