@@ -1,7 +1,7 @@
 // drumkv1widget_env.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -25,7 +25,7 @@
 #include <QPainterPath>
 #include <QMouseEvent>
 
-#include <math.h>
+#include <cmath>
 
 
 // Safe value capping.
