@@ -1,7 +1,7 @@
 // drumkv1widget_sample.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -24,7 +24,7 @@
 
 #include <QFrame>
 
-#include <stdint.h>
+#include <cstdint>
 
 
 // Forward decl.
